## 0.2.0 (2025-07-08)

### Feat

- Enhance Sprint and Epic Tools with validation and message formatting improvements
- **STORY-00C86631**: Implement validate_input abstract method and resolve critical linting issues

### Fix

- Resolve UnboundLocalError in epic tools list_epics
- Resolve TOML parse errors and mypy import issues
- Resolve critical TOML parse errors and type annotation issues

## v0.2.2 (2025-07-08)

### Refactor

- encapsulate CLI call in main function

## v0.2.1 (2025-07-08)

### Fix

- remove unused import in test_sprint_service.py

## v0.2.0 (2025-07-08)

### Feat

- Enhance Sprint and Epic Tools with validation and message formatting improvements
- **STORY-00C86631**: Implement validate_input abstract method and resolve critical linting issues

### Fix

- Resolve UnboundLocalError in epic tools list_epics
- Resolve TOML parse errors and mypy import issues
- Resolve critical TOML parse errors and type annotation issues
